aboutsummaryrefslogtreecommitdiff
path: root/qtmips_machine/machineconfig.h
diff options
context:
space:
mode:
Diffstat (limited to 'qtmips_machine/machineconfig.h')
-rw-r--r--qtmips_machine/machineconfig.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/qtmips_machine/machineconfig.h b/qtmips_machine/machineconfig.h
index b8504b4..987f3aa 100644
--- a/qtmips_machine/machineconfig.h
+++ b/qtmips_machine/machineconfig.h
@@ -65,8 +65,8 @@ public:
};
enum WritePolicy {
- WP_TROUGH_NOALLOC, // Write trough
- WP_TROUGH_ALLOC, // Write trough
+ WP_THROUGH_NOALLOC, // Write through
+ WP_THROUGH_ALLOC, // Write through
WP_BACK // Write back
};